@@ -29,6 +29,9 @@ DEFAULTS = {
 
     "CREATE_LOG_CLASS": "mad_webhooks.webhook.CreateLogClass",
     "POST_EVENT_TO_WEBHOOK_CLASS": "mad_webhooks.webhook.PostEventToWebhookClass",
+    
+    "MAKE_EVENT_FROM_LOG_TASK_CLASS": "mad_webhooks.tasks.MakeEventFromLogTaskClass",
+    "POST_EVENT_TO_WEBHOOK_TASK_CLASS": "mad_webhooks.tasks.PostEventToWebhookTaskClass",
 
     "WEBHOOK_USER_AGENT": "mad_webhooks",
 }
@@ -46,6 +49,9 @@ IMPORT_STRINGS = (
 
     "CREATE_LOG_CLASS",
     "POST_EVENT_TO_WEBHOOK_CLASS",
+
+    "MAKE_EVENT_FROM_LOG_TASK_CLASS",
+    "POST_EVENT_TO_WEBHOOK_TASK_CLASS",
 )
 
 MANDATORY = IMPORT_STRINGS
