@@ -1,6 +1,6 @@
 
 from mad_webhooks.models import get_log_model, get_webhook_event_post_attempt_model
-from oauth2_provider.models import get_access_token_model, get_application_model
+from oauth2_provider.models import get_application_model
 from mad_webhooks.settings import webhook_settings
 import logging
 import requests
@@ -48,7 +48,8 @@ class PostEventToWebhookClass:
     def postEventToWebhooks(self):
         # event = Event.objects.get(id=event.id)
         # for each endpoint send the event to the webhook via POST
-        for webhook in self.webhooks:
+        webhooks = self.webhooks
+        for webhook in webhooks:
             # make query
             query_params = webhook.query_params
 
@@ -78,49 +79,19 @@ class PostEventToWebhookClass:
                     'status_code': send.status_code,
                     'text': send.text
                 }
-            except requests.RequestException as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.ConnectionError as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.HTTPError as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.URLRequired as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.TooManyRedirects as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.ConnectTimeout as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.ReadTimeout as err:
-                r = {
-                    'status_code': None,
-                    'text': err
-                }
-            except requests.Timeout as err:
+
+                self.event.is_processed = True
+                self.event.save()
+
+            except Exception as err:
                 r = {
                     'status_code': None,
                     'text': err
                 }
 
+            # save post attempt data
             try:
-                save_response = get_webhook_event_post_attempt_model().objects.create(
+                get_webhook_event_post_attempt_model().objects.create(
                     application = self.event.application,
                     event = self.event,
                     endpoint_url = str(webhook.endpoint_url),
@@ -128,10 +99,8 @@ class PostEventToWebhookClass:
                     response_data = r['text'],
                 )
             except Exception as e:
-                logger.warning("Enable to Post: " + str(e))
+                logger.error("Unable to Post: " + str(e))
 
-        self.event.is_processed = True
-        self.event.save()
 
 
 
